securemix library
A production-grade, cryptographically secure password and passphrase generator with mutation engine and CLI support for Dart and Flutter.
Classes
- EvaluationResult
- Result of password evaluation.
- PasswordOptions
- Options for password generation.
- SecureMix
- Primary SecureMix functionality class.
Extensions
- SecureMixStringExtension on String
- Ergonomic String extension methods for SecureMix.
Constants
- secureMixVersion → const String
- Current version of the securemix package.
Functions
-
enhance(
String password) → String - Mutates a weak password into a strong one using the Mutation Engine.
-
enhancePassword(
String password) → String -
evaluate(
String password) → EvaluationResult - Evaluates password strength.
-
evaluatePassword(
String password) → EvaluationResult -
fromPattern(
String pattern) → String - Generates a password from a pattern (e.g. "AA-99-@a").
-
generate(
{int length = 12, PasswordOptions? options, bool? excludeSimilar, String? customCharset, bool? symbols, bool? numbers, bool? uppercase, bool? lowercase, int? batch}) → dynamic - Concise top-level password generator.
-
generateFromPattern(
String pattern) → String -
generateList(
{int length = 12, int batch = 5, PasswordOptions? options, bool? excludeSimilar, String? customCharset, bool? symbols, bool? numbers, bool? uppercase, bool? lowercase}) → List< String> - Concise top-level batch password generator alias.
-
generateMany(
{int length = 12, int batch = 5, PasswordOptions? options, bool? excludeSimilar, String? customCharset, bool? symbols, bool? numbers, bool? uppercase, bool? lowercase}) → List< String> - Concise top-level batch password generator.
-
generatePassword(
{int length = 12, PasswordOptions? options, bool? excludeSimilar, String? customCharset, bool? symbols, bool? numbers, bool? uppercase, bool? lowercase, int? batch}) → dynamic -
generatePasswordBatch(
{int length = 12, int batch = 5, PasswordOptions? options, bool? excludeSimilar, String? customCharset, bool? symbols, bool? numbers, bool? uppercase, bool? lowercase}) → List< String> -
generatePasswordString(
{int length = 12, PasswordOptions? options, bool? excludeSimilar, String? customCharset, bool? symbols, bool? numbers, bool? uppercase, bool? lowercase}) → String