SecureMixStringExtension extension
Ergonomic String extension methods for SecureMix.
- on
Properties
- isStrong → bool
-
Available on String, provided by the SecureMixStringExtension extension
Returns true if this password is rated strong (score >= 3).no setter - isWeak → bool
-
Available on String, provided by the SecureMixStringExtension extension
Returns true if this password is rated weak (score < 2).no setter - passwordScore → int
-
Available on String, provided by the SecureMixStringExtension extension
Returns the password security score (0 to 4).no setter
Methods
-
enhance(
) → String -
Available on String, provided by the SecureMixStringExtension extension
Enhances this string into a strong password using the Mutation Engine. -
evaluate(
) → EvaluationResult -
Available on String, provided by the SecureMixStringExtension extension
Evaluates the password strength of this string.